@@ -1,5 +1,3 @@
-# from contextlib import AbstractContextManager
-
 import logging
 
 import httpx
@@ -16,9 +14,6 @@ def parse_error_code(error_code):
 class BaseHTTPAdapter:
     client = None
 
-    def get(self, url):
-        raise NotImplementedError
-
     def get_with_data(self, url, data):
         raise NotImplementedError
 
@@ -31,25 +26,17 @@ class AsyncHTTPAdapter(BaseHTTPAdapter):
 
 
 class SyncHTTPAdapter(BaseHTTPAdapter):
-    client = httpx.Client(base_url=API_BASE_URL)
-
     def get_with_data(self, url, data):
         logger.debug(f"[SyncHTTPAdapter:get_with_data] URL: {url}")
-        with self.client as client:
+
+        with httpx.Client(base_url=API_BASE_URL) as client:
             response = client.request(method="GET", url=url, json=data)
             return response.json()
 
-    def get(self, url):
-        logger.debug(f"[SyncHTTPAdapter:get] URL: {url}")
-
-        with self.client as client:
-            response = client.get(url)
-            return response.json()
-
     def post(self, url, data):
         logger.debug(f"[SyncHTTPAdapter:post] URL: {url}")
 
-        with self.client as client:
+        with httpx.Client(base_url=API_BASE_URL) as client:
             response = client.post(url, json=data)
             return response.json()
 
